"use strict";(self.webpackChunkcentreon=self.webpackChunkcentreon||[]).push([["9057"],{84436:function(e,n,t){t.r(n);var u=t(91942),r=t(81556),a=t(20718),c=t(1975);n.default=function(){var e=(0,u.useTranslation)().t;return c.createElement(r.E,{message:e(a.pi),title:"404"})}},20718:function(e,n,t){t.d(n,{pi:function(){return u}});var u="This page could not be found"}}]);
//# sourceMappingURL=9057.7dfd74bb7a3affef6f30.247497909764ed5ccbc0.5afebcb571c07722777f.js.map