"use strict";(self.webpackChunkcentreon=self.webpackChunkcentreon||[]).push([["4282"],{545:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.T3);t.Z=u},27445:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.kn);t.Z=u},29907:function(n,t,e){e.d(t,{E:function(){return r}});var r=(0,e(26017).atom)([])},19972:function(n,t,e){e.d(t,{F:function(){return r}});var r=(0,e(26017).atom)(navigator.language.slice(0,2))},91486:function(n,t,e){var r=(0,e(26017).atom)(!1);t.Z=r},44949:function(n,t,e){e.d(t,{Bt:function(){return o},Ml:function(){return c},T3:function(){return f},YO:function(){return a},kn:function(){return i},yK:function(){return u}});var r=e(30093),o={alias:"",canManageApiTokens:!1,default_page:"/monitoring/resources",id:void 0,isAdmin:void 0,isExportButtonEnabled:!1,locale:null,name:"",themeMode:r.hY.light,timezone:Intl.DateTimeFormat().resolvedOptions().timeZone,use_deprecated_pages:!1,user_interface_density:r.jq.compact},u=!1,i={actions:{host:{acknowledgement:!1,check:!1,comment:!1,disacknowledgement:!1,downtime:!1,submit_status:!1},service:{acknowledgement:!1,check:!1,comment:!1,disacknowledgement:!1,downtime:!1,submit_status:!1}}},a={duration:3600,fixed:!0,with_services:!1},c=15,f={force_active_checks:!1,notify:!0,persistent:!1,sticky:!1,with_services:!0}},86574:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.YO);t.Z=u},33677:function(n,t,e){e.d(t,{E:function(){return o},u:function(){return u}});var r=e(26017),o=(0,r.atom)(null),u=(0,r.atom)(null)},8973:function(n,t,e){e.r(t),e.d(t,{DashboardGlobalRole:function(){return d.ex},ListingVariant:function(){return d.jq},ThemeMode:function(){return d.hY},acknowledgementAtom:function(){return f.Z},aclAtom:function(){return o.Z},additionalResourcesAtom:function(){return A.E},browserLocaleAtom:function(){return k.F},cloudServicesAtom:function(){return c.Z},downtimeAtom:function(){return u.Z},featureFlagsDerivedAtom:function(){return v.z},federatedModulesAtom:function(){return Z.E},federatedWidgetsAtom:function(){return Z.u},isOnPublicPageAtom:function(){return h.q},isResourceStatusFullSearchEnabledAtom:function(){return p.B},platformFeaturesAtom:function(){return v.S},platformNameAtom:function(){return s.Z},platformVersionsAtom:function(){return g.z},refreshIntervalAtom:function(){return i.Z},resourceStorageOptimizationModeAtom:function(){return m.Z},statisticsRefreshIntervalAtom:function(){return a.Z},userAtom:function(){return r.Z},userPermissionsAtom:function(){return l.Z}});var r=e(62416),o=e(27445),u=e(86574),i=e(66992),a=e(61330),c=e(91486),f=e(545),m=e(75019),s=e(84289),l=e(57162),d=e(30093),v=e(51058),g=e(4067),h=e(28837),A=e(29907),Z=e(33677),k=e(19972),p=e(23279)},28837:function(n,t,e){e.d(t,{q:function(){return r}});var r=(0,e(26017).atom)(!1)},23279:function(n,t,e){e.d(t,{B:function(){return r}});var r=(0,e(26017).atom)(!1)},51058:function(n,t,e){e.d(t,{S:function(){return o},z:function(){return u}});var r=e(26017),o=(0,r.atom)(null),u=(0,r.atom)(function(n){var t=n(o);return null==t?void 0:t.featureFlags})},84289:function(n,t,e){var r=(0,e(26017).atom)(null);t.Z=r},4067:function(n,t,e){e.d(t,{z:function(){return r}});var r=(0,e(26017).atom)(null)},66992:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.Ml);t.Z=u},75019:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.yK);t.Z=u},61330:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.Ml);t.Z=u},30093:function(n,t,e){var r,o,u,i,a,c;e.d(t,{ex:function(){return o},hY:function(){return u},jq:function(){return r}}),(i=r||(r={})).compact="compact",i.extended="extended",(a=o||(o={})).administrator="administrator",a.creator="creator",a.viewer="viewer",(c=u||(u={})).dark="dark",c.light="light"},62416:function(n,t,e){var r=e(26017),o=e(44949),u=(0,r.atom)(o.Bt);t.Z=u},57162:function(n,t,e){var r=(0,e(26017).atom)(null);t.Z=r}}]);
//# sourceMappingURL=4282.64519ee652024441274c.4ab40e9c5e3c3a0e2dd9.5afebcb571c07722777f.js.map